@@ -26,6 +26,7 @@ class TwitterExtractor(Extractor):
     cookiedomain = ".twitter.com"
     cookienames = ("auth_token",)
     root = "https://twitter.com"
+    browser = "firefox"
 
     def __init__(self, match):
         Extractor.__init__(self, match)
@@ -40,6 +41,10 @@ class TwitterExtractor(Extractor):
         self.cards = self.config("cards", False)
         self.cards_blacklist = self.config("cards-blacklist")
         self.syndication = self.config("syndication")
+
+        if not self.config("transform", True):
+            self._transform_user = util.identity
+            self._transform_tweet = util.identity
         self._user = self._user_obj = None
         self._user_cache = {}
         self._init_sizes()
@@ -211,7 +216,7 @@ class TwitterExtractor(Extractor):
                             files.append(value)
                             return
         elif name == "unified_card":
-            data = json.loads(bvals["unified_card"]["string_value"])
+            data = util.json_loads(bvals["unified_card"]["string_value"])
             self._extract_media(tweet, data["media_entities"].values(), files)
             return
 
@@ -243,11 +248,15 @@ class TwitterExtractor(Extractor):
             author = tweet["user"]
         author = self._transform_user(author)
 
+        if "note_tweet" in tweet:
+            note = tweet["note_tweet"]["note_tweet_results"]["result"]
+        else:
+            note = None
+
         if "legacy" in tweet:
             tweet = tweet["legacy"]
 
         tget = tweet.get
-        entities = tweet["entities"]
         tdata = {
             "tweet_id"      : text.parse_int(tweet["id_str"]),
             "retweet_id"    : text.parse_int(
@@ -267,6 +276,8 @@ class TwitterExtractor(Extractor):
             "retweet_count" : tget("retweet_count"),
         }
 
+        entities = note["entity_set"] if note else tweet["entities"]
+
         hashtags = entities.get("hashtags")
         if hashtags:
             tdata["hashtags"] = [t["text"] for t in hashtags]
@@ -279,7 +290,8 @@ class TwitterExtractor(Extractor):
                 "nick": u["name"],
             } for u in mentions]
 
-        content = text.unescape(tget("full_text") or tget("text") or "")
+        content = text.unescape(
+            note["text"] if note else tget("full_text") or tget("text") or "")
         urls = entities.get("urls")
         if urls:
             for url in urls:
@@ -637,6 +649,21 @@ class TwitterSearchExtractor(TwitterExtractor):
         return self.api.search_adaptive(query)
 
 
+class TwitterHashtagExtractor(TwitterExtractor):
+    """Extractor for Twitter hashtags"""
+    subcategory = "hashtag"
+    pattern = BASE_PATTERN + r"/hashtag/([^/?#]+)"
+    test = ("https://twitter.com/hashtag/nature", {
+        "pattern": TwitterSearchExtractor.pattern,
+        "url": "3571c3a53b7647ea35517041fdc17f77ec5b2cb9",
+    })
+
+    def items(self):
+        url = "{}/search?q=%23{}".format(self.root, self.user)
+        data = {"_extractor": TwitterSearchExtractor}
+        yield Message.Queue, url, data
+
+
 class TwitterEventExtractor(TwitterExtractor):
     """Extractor for Tweets from a Twitter Event"""
     subcategory = "event"
@@ -798,6 +825,23 @@ class TwitterTweetExtractor(TwitterExtractor):
                        r"\?format=(jpg|png)&name=orig$",
             "range": "1-2",
         }),
+        # note tweet with long 'content'
+        ("https://twitter.com/i/web/status/1629193457112686592", {
+            "keyword": {
+                "content": """\
+BREAKING - DEADLY LIES: Independent researchers at Texas A&M University have \
+just contradicted federal government regulators, saying that toxic air \
+pollutants in East Palestine, Ohio, could pose long-term risks. \n\nThe \
+Washington Post writes, "Three weeks after the toxic train derailment in \
+Ohio, an analysis of Environmental Protection Agency data has found nine air \
+pollutants at levels that could raise long-term health concerns in and around \
+East Palestine, according to an independent analysis. \n\n\"The analysis by \
+Texas A&M University seems to contradict statements by state and federal \
+regulators that air near the crash site is completely safe, despite residents \
+complaining about rashes, breathing problems and other health effects." \
+Your reaction.""",
+            },
+        }),
     )
 
     def __init__(self, match):
@@ -945,63 +989,7 @@ class TwitterAPI():
     def __init__(self, extractor):
         self.extractor = extractor
 
-        self.root = "https://twitter.com/i/api"
-        self.headers = {
-            "authorization": "Bearer AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejR"
-                             "COuH5E6I8xnZz4puTs%3D1Zv7ttfk8LF81IUq16cHjhLTvJu"
-                             "4FA33AGWWjCpTnA",
-            "x-guest-token": None,
-            "x-twitter-auth-type": None,
-            "x-twitter-client-language": "en",
-            "x-twitter-active-user": "yes",
-            "x-csrf-token": None,
-            "Referer": "https://twitter.com/",
-        }
-        self.params = {
-            "include_profile_interstitial_type": "1",
-            "include_blocking": "1",
-            "include_blocked_by": "1",
-            "include_followed_by": "1",
-            "include_want_retweets": "1",
-            "include_mute_edge": "1",
-            "include_can_dm": "1",
-            "include_can_media_tag": "1",
-            "include_ext_has_nft_avatar": "1",
-            "skip_status": "1",
-            "cards_platform": "Web-12",
-            "include_cards": "1",
-            "include_ext_alt_text": "true",
-            "include_quote_count": "true",
-            "include_reply_count": "1",
-            "tweet_mode": "extended",
-            "include_entities": "true",
-            "include_user_entities": "true",
-            "include_ext_media_color": "true",
-            "include_ext_media_availability": "true",
-            "include_ext_sensitive_media_warning": "true",
-            "send_error_codes": "true",
-            "simple_quoted_tweet": "true",
-            "count": "100",
-            "cursor": None,
-            "ext": "mediaStats,highlightedLabel,hasNftAvatar,"
-                   "voiceInfo,superFollowMetadata",
-        }
-        self.variables = {
-            "includePromotedContent": False,
-            "withSuperFollowsUserFields": True,
-            "withBirdwatchPivots": False,
-            "withDownvotePerspective": False,
-            "withReactionsMetadata": False,
-            "withReactionsPerspective": False,
-            "withSuperFollowsTweetFields": True,
-            "withClientEventToken": False,
-            "withBirdwatchNotes": False,
-            "withVoice": True,
-            "withV2Timeline": False,
-            "__fs_interactive_text": False,
-            "__fs_dont_mention_me_view_api_enabled": False,
-        }
-
+        self.root = "https://api.twitter.com"
         self._nsfw_warning = True
         self._syndication = self.extractor.syndication
         self._json_dumps = json.JSONEncoder(separators=(",", ":")).encode
@@ -1017,65 +1005,193 @@ class TwitterAPI():
         if not csrf_token:
             csrf_token = util.generate_token()
             cookies.set("ct0", csrf_token, domain=cookiedomain)
-        self.headers["x-csrf-token"] = csrf_token
 
-        if cookies.get("auth_token", domain=cookiedomain):
-            # logged in
-            self.headers["x-twitter-auth-type"] = "OAuth2Session"
-        else:
-            # guest
-            guest_token = self._guest_token()
-            cookies.set("gt", guest_token, domain=cookiedomain)
-            self.headers["x-guest-token"] = guest_token
+        auth_token = cookies.get("auth_token", domain=cookiedomain)
+
+        if not auth_token:
+            self.user_media = self.user_media_legacy
+
+        self.headers = {
+            "Accept": "*/*",
+            "authorization": "Bearer AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejR"
+                             "COuH5E6I8xnZz4puTs%3D1Zv7ttfk8LF81IUq16cHjhLTvJu"
+                             "4FA33AGWWjCpTnA",
+            "x-guest-token": None,
+            "x-twitter-auth-type": "OAuth2Session" if auth_token else None,
+            "x-twitter-client-language": "en",
+            "x-twitter-active-user": "yes",
+            "x-csrf-token": csrf_token,
+            "Origin": "https://twitter.com",
+            "Referer": "https://twitter.com/",
+        }
+        self.params = {
+            "include_profile_interstitial_type": "1",
+            "include_blocking": "1",
+            "include_blocked_by": "1",
+            "include_followed_by": "1",
+            "include_want_retweets": "1",
+            "include_mute_edge": "1",
+            "include_can_dm": "1",
+            "include_can_media_tag": "1",
+            "include_ext_has_nft_avatar": "1",
+            "include_ext_is_blue_verified": "1",
+            "include_ext_verified_type": "1",
+            "skip_status": "1",
+            "cards_platform": "Web-12",
+            "include_cards": "1",
+            "include_ext_alt_text": "true",
+            "include_ext_limited_action_results": "false",
+            "include_quote_count": "true",
+            "include_reply_count": "1",
+            "tweet_mode": "extended",
+            "include_ext_collab_control": "true",
+            "include_ext_views": "true",
+            "include_entities": "true",
+            "include_user_entities": "true",
+            "include_ext_media_color": "true",
+            "include_ext_media_availability": "true",
+            "include_ext_sensitive_media_warning": "true",
+            "include_ext_trusted_friends_metadata": "true",
+            "send_error_codes": "true",
+            "simple_quoted_tweet": "true",
+            "q": None,
+            "count": "100",
+            "query_source": None,
+            "cursor": None,
+            "pc": None,
+            "spelling_corrections": None,
+            "include_ext_edit_control": "true",
+            "ext": "mediaStats,highlightedLabel,hasNftAvatar,voiceInfo,"
+                   "enrichments,superFollowMetadata,unmentionInfo,editControl,"
+                   "collab_control,vibe",
+        }
+        self.variables = {
+            "withDownvotePerspective": False,
+            "withReactionsMetadata": False,
+            "withReactionsPerspective": False,
+        }
+        self.features = {
+            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
+            "responsive_web_graphql_exclude_directive_enabled": True,
+            "verified_phone_label_enabled": False,
+            "responsive_web_graphql_skip_user_profile_"
+            "image_extensions_enabled": False,
+            "responsive_web_graphql_timeline_navigation_enabled": True,
+        }
+        self.features_pagination = {
+            "responsive_web_twitter_blue_verified_badge_is_enabled": True,
+            "responsive_web_graphql_exclude_directive_enabled": True,
+            "verified_phone_label_enabled": False,
+            "responsive_web_graphql_timeline_navigation_enabled": True,
+            "responsive_web_graphql_skip_user_profile_"
+            "image_extensions_enabled": False,
+            "tweetypie_unmention_optimization_enabled": True,
+            "vibe_api_enabled": True,
+            "responsive_web_edit_tweet_api_enabled": True,
+            "graphql_is_translatable_rweb_tweet_is_translatable_enabled": True,
+            "view_counts_everywhere_api_enabled": True,
+            "longform_notetweets_consumption_enabled": True,
+            "tweet_awards_web_tipping_enabled": False,
+            "freedom_of_speech_not_reach_fetch_enabled": False,
+            "standardized_nudges_misinfo": True,
+            "tweet_with_visibility_results_prefer_gql_"
+            "limited_actions_policy_enabled": False,
+            "interactive_text_enabled": True,
+            "responsive_web_text_conversations_enabled": False,
+            "longform_notetweets_richtext_consumption_enabled": False,
+            "responsive_web_enhance_cards_enabled": False,
+        }
 
     def tweet_detail(self, tweet_id):
-        endpoint = "/graphql/ItejhtHVxU7ksltgMmyaLA/TweetDetail"
+        endpoint = "/graphql/zXaXQgfyR4GxE21uwYQSyA/TweetDetail"
         variables = {
             "focalTweetId": tweet_id,
+            "referrer": "profile",
             "with_rux_injections": False,
+            "includePromotedContent": True,
             "withCommunity": True,
             "withQuickPromoteEligibilityTweetFields": True,
             "withBirdwatchNotes": False,
+            "withSuperFollowsUserFields": True,
+            "withSuperFollowsTweetFields": True,
+            "withVoice": True,
+            "withV2Timeline": True,
         }
         return self._pagination_tweets(
-            endpoint, variables, ("threaded_conversation_with_injections",))
+            endpoint, variables, ("threaded_conversation_with_injections_v2",))
 
     def user_tweets(self, screen_name):
-        endpoint = "/graphql/WZT7sCTrLvSOaWOXLDsWbQ/UserTweets"
+        endpoint = "/graphql/9rys0A7w1EyqVd2ME0QCJg/UserTweets"
         variables = {
             "userId": self._user_id_by_screen_name(screen_name),
             "count": 100,
+            "includePromotedContent": True,
             "withQuickPromoteEligibilityTweetFields": True,
+            "withVoice": True,
+            "withV2Timeline": True,
         }
         return self._pagination_tweets(endpoint, variables)
 
     def user_tweets_and_replies(self, screen_name):
-        endpoint = "/graphql/t4wEKVulW4Mbv1P0kgxTEw/UserTweetsAndReplies"
+        endpoint = "/graphql/ehMCHF3Mkgjsfz_aImqOsg/UserTweetsAndReplies"
         variables = {
             "userId": self._user_id_by_screen_name(screen_name),
             "count": 100,
+            "includePromotedContent": True,
             "withCommunity": True,
+            "withVoice": True,
+            "withV2Timeline": True,
         }
         return self._pagination_tweets(endpoint, variables)
 
     def user_media(self, screen_name):
+        endpoint = "/graphql/MA_EP2a21zpzNWKRkaPBMg/UserMedia"
+        variables = {
+            "userId": self._user_id_by_screen_name(screen_name),
+            "count": 100,
+            "includePromotedContent": False,
+            "withClientEventToken": False,
+            "withBirdwatchNotes": False,
+            "withVoice": True,
+            "withV2Timeline": True,
+        }
+        return self._pagination_tweets(endpoint, variables)
+
+    def user_media_legacy(self, screen_name):
         endpoint = "/graphql/nRybED9kRbN-TOWioHq1ng/UserMedia"
         variables = {
             "userId": self._user_id_by_screen_name(screen_name),
             "count": 100,
+            "includePromotedContent": False,
+            "withSuperFollowsUserFields": True,
+            "withBirdwatchPivots": False,
+            "withSuperFollowsTweetFields": True,
+            "withClientEventToken": False,
+            "withBirdwatchNotes": False,
+            "withVoice": True,
+            "withV2Timeline": False,
+            "__fs_interactive_text": False,
+            "__fs_dont_mention_me_view_api_enabled": False,
         }
-        return self._pagination_tweets(endpoint, variables)
+        return self._pagination_tweets(
+            endpoint, variables, ("user", "result", "timeline", "timeline"),
+            features=False)
 
     def user_likes(self, screen_name):
-        endpoint = "/graphql/9MSTt44HoGjVFSg_u3rHDw/Likes"
+        endpoint = "/graphql/XbHBYpgURwtklXj8NNxTDw/Likes"
         variables = {
             "userId": self._user_id_by_screen_name(screen_name),
             "count": 100,
+            "includePromotedContent": False,
+            "withClientEventToken": False,
+            "withBirdwatchNotes": False,
+            "withVoice": True,
+            "withV2Timeline": True,
         }
         return self._pagination_tweets(endpoint, variables)
 
     def user_bookmarks(self):
-        endpoint = "/graphql/uKP9v_I31k0_VSBmlpq2Xg/Bookmarks"
+        endpoint = "/graphql/Xq0wQSWHlcfnXARLJGqTxg/Bookmarks"
         variables = {
             "count": 100,
         }
@@ -1083,7 +1199,7 @@ class TwitterAPI():
             endpoint, variables, ("bookmark_timeline", "timeline"), False)
 
     def list_latest_tweets_timeline(self, list_id):
-        endpoint = "/graphql/z3l-EHlx-fyg8OvGO4JN8A/ListLatestTweetsTimeline"
+        endpoint = "/graphql/FDI9EiIp54KxEOWGiv3B4A/ListLatestTweetsTimeline"
         variables = {
             "listId": list_id,
             "count": 100,
@@ -1118,18 +1234,21 @@ class TwitterAPI():
                 ["twitter_objects"]["live_events"][event_id])
 
     def list_by_rest_id(self, list_id):
-        endpoint = "/graphql/BWEhzAk7k8TwbU4lKH2dpw/ListByRestId"
-        params = {"variables": self._json_dumps({
-            "listId": list_id,
-            "withSuperFollowsUserFields": True,
-        })}
+        endpoint = "/graphql/KlGpwq5CAt9tCfHkV2mwYQ/ListByRestId"
+        params = {
+            "variables": self._json_dumps({
+                "listId": list_id,
+                "withSuperFollowsUserFields": True,
+            }),
+            "features": self._json_dumps(self.features),
+        }
         try:
             return self._call(endpoint, params)["data"]["list"]
         except KeyError:
             raise exception.NotFoundError("list")
 
     def list_members(self, list_id):
-        endpoint = "/graphql/snESM0DPs3c7M1SBm4rvVw/ListMembers"
+        endpoint = "/graphql/XsAJX17RLgLYU8GALIWg2g/ListMembers"
         variables = {
             "listId": list_id,
             "count": 100,
@@ -1139,29 +1258,34 @@ class TwitterAPI():
             endpoint, variables, ("list", "members_timeline", "timeline"))
 
     def user_following(self, screen_name):
-        endpoint = "/graphql/mIwX8GogcobVlRwlgpHNYA/Following"
+        endpoint = "/graphql/vTZwBbd_gz6aI8v6Wze21A/Following"
         variables = {
             "userId": self._user_id_by_screen_name(screen_name),
             "count": 100,
+            "includePromotedContent": False,
         }
         return self._pagination_users(endpoint, variables)
 
     def user_by_rest_id(self, rest_id):
-        endpoint = "/graphql/I5nvpI91ljifos1Y3Lltyg/UserByRestId"
-        params = {"variables": self._json_dumps({
-            "userId": rest_id,
-            "withSafetyModeUserFields": True,
-            "withSuperFollowsUserFields": True,
-        })}
+        endpoint = "/graphql/QPSxc9lxrmrwnBzYkJI8eA/UserByRestId"
+        params = {
+            "variables": self._json_dumps({
+                "userId": rest_id,
+                "withSafetyModeUserFields": True,
+            }),
+            "features": self._json_dumps(self.features),
+        }
         return self._call(endpoint, params)["data"]["user"]["result"]
 
     def user_by_screen_name(self, screen_name):
-        endpoint = "/graphql/7mjxD3-C6BxitPMVQ6w0-Q/UserByScreenName"
-        params = {"variables": self._json_dumps({
-            "screen_name": screen_name,
-            "withSafetyModeUserFields": True,
-            "withSuperFollowsUserFields": True,
-        })}
+        endpoint = "/graphql/nZjSkpOpSL5rWyIVdsKeLA/UserByScreenName"
+        params = {
+            "variables": self._json_dumps({
+                "screen_name": screen_name,
+                "withSafetyModeUserFields": True,
+            }),
+            "features": self._json_dumps(self.features),
+        }
         return self._call(endpoint, params)["data"]["user"]["result"]
 
     def _user_id_by_screen_name(self, screen_name):
@@ -1183,17 +1307,26 @@ class TwitterAPI():
 
     @cache(maxage=3600)
     def _guest_token(self):
-        root = "https://api.twitter.com"
         endpoint = "/1.1/guest/activate.json"
-        return str(self._call(endpoint, None, root, "POST")["guest_token"])
+        self.extractor.log.info("Requesting guest token")
+        return str(self._call(endpoint, None, "POST", False)["guest_token"])
 
-    def _call(self, endpoint, params, root=None, method="GET"):
-        if root is None:
-            root = self.root
+    def _authenticate_guest(self):
+        guest_token = self._guest_token()
+        if guest_token != self.headers["x-guest-token"]:
+            self.headers["x-guest-token"] = guest_token
+            self.extractor.session.cookies.set(
+                "gt", guest_token, domain=self.extractor.cookiedomain)
+
+    def _call(self, endpoint, params, method="GET", auth=True):
+        url = self.root + endpoint
 
         while True:
+            if not self.headers["x-twitter-auth-type"] and auth:
+                self._authenticate_guest()
+
             response = self.extractor.request(
-                root + endpoint, method=method, params=params,
+                url, method=method, params=params,
                 headers=self.headers, fatal=None)
 
             # update 'x-csrf-token' header (#1170)
@@ -1226,21 +1359,33 @@ class TwitterAPI():
 
     def _pagination_legacy(self, endpoint, params):
         original_retweets = (self.extractor.retweets == "original")
+        bottom = ("cursor-bottom-", "sq-cursor-bottom")
 
         while True:
             data = self._call(endpoint, params)
 
-            instr = data["timeline"]["instructions"]
-            if not instr:
+            instructions = data["timeline"]["instructions"]
+            if not instructions:
                 return
 
             tweets = data["globalObjects"]["tweets"]
             users = data["globalObjects"]["users"]
             tweet_id = cursor = None
             tweet_ids = []
+            entries = ()
+
+            # process instructions
+            for instr in instructions:
+                if "addEntries" in instr:
+                    entries = instr["addEntries"]["entries"]
+                elif "replaceEntry" in instr:
+                    entry = instr["replaceEntry"]["entry"]
+                    if entry["entryId"].startswith(bottom):
+                        cursor = (entry["content"]["operation"]
+                                  ["cursor"]["value"])
 
             # collect tweet IDs and cursor value
-            for entry in instr[0]["addEntries"]["entries"]:
+            for entry in entries:
                 entry_startswith = entry["entryId"].startswith
 
                 if entry_startswith(("tweet-", "sq-I-t-")):
@@ -1252,7 +1397,7 @@ class TwitterAPI():
                         entry["content"]["timelineModule"]["metadata"]
                         ["conversationMetadata"]["allTweetIds"][::-1])
 
-                elif entry_startswith(("cursor-bottom-", "sq-cursor-bottom")):
+                elif entry_startswith(bottom):
                     cursor = entry["content"]["operation"]["cursor"]
                     if not cursor.get("stopOnEmptyResponse", True):
                         # keep going even if there are no tweets
@@ -1300,29 +1445,29 @@ class TwitterAPI():
                         quoted["quoted_by_id_str"] = tweet["id_str"]
                         yield quoted
 
-            # update cursor value
-            if "replaceEntry" in instr[-1] :
-                cursor = (instr[-1]["replaceEntry"]["entry"]
-                          ["content"]["operation"]["cursor"]["value"])
-
+            # stop on empty response
             if not cursor or (not tweets and not tweet_id):
                 return
             params["cursor"] = cursor
 
     def _pagination_tweets(self, endpoint, variables,
-                           path=None, stop_tweets=True):
+                           path=None, stop_tweets=True, features=True):
         extr = self.extractor
         variables.update(self.variables)
         original_retweets = (extr.retweets == "original")
         pinned_tweet = extr.pinned
 
+        params = {"variables": None}
+        if features:
+            params["features"] = self._json_dumps(self.features_pagination)
+
         while True:
-            params = {"variables": self._json_dumps(variables)}
+            params["variables"] = self._json_dumps(variables)
             data = self._call(endpoint, params)["data"]
 
             try:
                 if path is None:
-                    instructions = (data["user"]["result"]["timeline"]
+                    instructions = (data["user"]["result"]["timeline_v2"]
                                     ["timeline"]["instructions"])
                 else:
                     instructions = data
@@ -1346,12 +1491,8 @@ class TwitterAPI():
                     if user.get("blocked_by"):
                         if self.headers["x-twitter-auth-type"] and \
                                 extr.config("logout"):
-                            guest_token = self._guest_token()
-                            extr.session.cookies.set(
-                                "gt", guest_token, domain=extr.cookiedomain)
                             extr._cookiefile = None
                             del extr.session.cookies["auth_token"]
-                            self.headers["x-guest-token"] = guest_token
                             self.headers["x-twitter-auth-type"] = None
                             extr.log.info("Retrying API request as guest")
                             continue
@@ -1417,6 +1558,8 @@ class TwitterAPI():
 
                 if "retweeted_status_result" in legacy:
                     retweet = legacy["retweeted_status_result"]["result"]
+                    if "tweet" in retweet:
+                        retweet = retweet["tweet"]
                     if original_retweets:
                         try:
                             retweet["legacy"]["retweeted_status_id_str"] = \
@@ -1462,10 +1605,12 @@ class TwitterAPI():
 
     def _pagination_users(self, endpoint, variables, path=None):
         variables.update(self.variables)
+        params = {"variables": None,
+                  "features" : self._json_dumps(self.features_pagination)}
 
         while True:
             cursor = entry = stop = None
-            params = {"variables": self._json_dumps(variables)}
+            params["variables"] = self._json_dumps(variables)
             data = self._call(endpoint, params)["data"]
 
             try:
@@ -1578,8 +1723,6 @@ def _login_impl(extr, username, password):
             "Login with email is no longer possible. "
             "You need to provide your username or phone number instead.")
 
-    extr.log.info("Logging in as %s", username)
-
     def process(response):
         try:
             data = response.json()
@@ -1598,8 +1741,10 @@ def _login_impl(extr, username, password):
 
     extr.session.cookies.clear()
     api = TwitterAPI(extr)
+    api._authenticate_guest()
     headers = api.headers
-    headers["Referer"] = "https://twitter.com/i/flow/login"
+
+    extr.log.info("Logging in as %s", username)
 
     # init
     data = {
@@ -1653,7 +1798,7 @@ def _login_impl(extr, username, password):
             "web_modal": 1,
         },
     }
-    url = "https://twitter.com/i/api/1.1/onboarding/task.json?flow_name=login"
+    url = "https://api.twitter.com/1.1/onboarding/task.json?flow_name=login"
     response = extr.request(url, method="POST", headers=headers, json=data)
 
     data = {
@@ -1668,7 +1813,7 @@ def _login_impl(extr, username, password):
             },
         ],
     }
-    url = "https://twitter.com/i/api/1.1/onboarding/task.json"
+    url = "https://api.twitter.com/1.1/onboarding/task.json"
     response = extr.request(
         url, method="POST", headers=headers, json=data, fatal=None)
 
@@ -1692,7 +1837,7 @@ def _login_impl(extr, username, password):
             },
         ],
     }
-    #  url = "https://twitter.com/i/api/1.1/onboarding/task.json"
+    #  url = "https://api.twitter.com/1.1/onboarding/task.json"
     extr.sleep(random.uniform(2.0, 4.0), "login (username)")
     response = extr.request(
         url, method="POST", headers=headers, json=data, fatal=None)
@@ -1710,7 +1855,7 @@ def _login_impl(extr, username, password):
             },
         ],
     }
-    #  url = "https://twitter.com/i/api/1.1/onboarding/task.json"
+    #  url = "https://api.twitter.com/1.1/onboarding/task.json"
     extr.sleep(random.uniform(2.0, 4.0), "login (password)")
     response = extr.request(
         url, method="POST", headers=headers, json=data, fatal=None)
@@ -1727,7 +1872,7 @@ def _login_impl(extr, username, password):
             },
         ],
     }
-    #  url = "https://twitter.com/i/api/1.1/onboarding/task.json"
+    #  url = "https://api.twitter.com/1.1/onboarding/task.json"
     response = extr.request(
         url, method="POST", headers=headers, json=data, fatal=None)
     process(response)
